@@ -23,9 +23,8 @@ def require_libs():
     reqs = 'gdbm', 'openssl@1.1', 'xz'
     cmd = ['brew', 'list', '--formula']
     installed = subprocess.check_output(cmd, text=True).strip().split()
-    assert set(reqs) < set(installed), "Need {missing}".format(
-        missing=set(reqs) - set(installed)
-    )
+    missing = set(reqs) - set(installed)
+    assert not missing, f"Need {missing}"
 
 
 @autocommand.autocommand(__name__)
